@@ -3,7 +3,9 @@ from gooey import Gooey, GooeyParser
 @Gooey
 def main():
     parser = GooeyParser(description="Gooey example")
-    parser.add_argument("-a", "--myargument", action="store_true")
+    parser.add_argument("-a", "--myargument", action="store_true", gooey_options={
+        'initial_value': True
+    })
     args = parser.parse_args()
     print(args)
     print(args.myargument)
